@@ -2,6 +2,7 @@ from pyfiglet import figlet_format
 from typing import List
 from colorama import Fore, Style
 import calendar
+from random import shuffle
 import textwrap as tr
 import sys
 import logging
@@ -18,13 +19,16 @@ config = Config()
 class Display:
     def __init__(
         self,
+        durations: Durations,
         theme_color: str = config.theme_color,
         pom_name: str = config.pom_name,
     ):
+        self.theme_color = theme_color
         self.theme = self.color_map(theme_color)
         self.pom_name = pom_name
+        self.durations = durations
 
-    def col(self, string: str, color: str = None):
+    def col(self, string: str, color: str = "white"):
         if color:
             return f"{self.color_map(color)}{string}{Style.RESET_ALL}"
         else:
@@ -66,14 +70,15 @@ class Display:
             f"{self.col('to stop timer.')}",
         )
 
-    def print_insights(self, durations: Durations):
+    def print_insights(self):
         print(
             f"\nTotal {self.col(self.add_plurality(self.pom_name), 'lmagenta')} today:          "
-            f"{self.col(str(int(durations.poms)), 'yellow')} {self.add_plurality(self.pom_name)}"
+            f"{self.col(str(int(self.durations.poms)), 'yellow')} "
+            f"{self.add_plurality(self.pom_name)}"
             f"\nTotal {self.col('Work', 'red')} today:           "
-            f"{self.col(str(int(durations.total_work_mins)), 'yellow')} minutes"
+            f"{self.col(str(int(self.durations.total_work_mins)), 'yellow')} minutes"
             f"\nTotal {self.col('Rest', 'green')} today:           "
-            f"{self.col(str(int(durations.total_rest_mins)), 'yellow')} minutes\n"
+            f"{self.col(str(int(self.durations.total_rest_mins)), 'yellow')} minutes\n"
             f"\n{self.col('Press')} "
             f"{self.col('ENTER', 'yellow')} "
             f"{self.col('to return to main menu.')}"
@@ -99,13 +104,6 @@ class Display:
             f"\n{self.col('Q', 'yellow')}{self.col('       --    Quit')}"
         )
 
-    def print_splash_prompt(self):
-        print(
-            f"\n{self.col('Press')} "
-            f"{self.col('ENTER', 'yellow')} "
-            f"{self.col('to start the next timer.')}"
-        )
-
     def print_offer_options(self):
         print(f"{self.col('Press')} {self.col('H', 'yellow')} {self.col('for Help.')}")
 
@@ -143,7 +141,7 @@ class Display:
             fix_str += " "
         return fix_str
 
-    def print_splash(self, durations: Durations, mode: str, tasks: List):
+    def print_splash(self, mode: str, tasks: List):
         print(
             self.col(
                 f"Tasks for today, {calendar.day_name[get_weekday()]} {get_today()}"
@@ -151,14 +149,18 @@ class Display:
         )
         print(self.col("-----------------------------------------"))
         self.print_tasks(tasks)
+
+    def print_splash_prompt(self, mode: str):
         print(
-            f"\n{self.col('Upcoming timer: ')}"
-            f"{self.col(mode.upper(), self._set_mode_color(mode, durations))}  "
+            f"\n{self.col('Press')} "
+            f"{self.col('ENTER', 'yellow')} "
+            f"{self.col('to start the')} "
+            f"{self.col(mode.upper(), self._set_mode_color(mode, self.durations))} "
+            f"{self.col('timer.')}"
         )
 
     def print_splash_variants(
         self,
-        durations: Durations,
         mode: str,
         is_options: bool = None,
         is_tasks: bool = None,
@@ -166,20 +168,20 @@ class Display:
     ):
         logger.info(f"Splash. is_options: {is_options} is_tasks: {is_tasks}")
         self.print_header_small()
-        self.print_splash(durations, mode, tasks)
+        self.print_splash(mode, tasks)
         if is_options is True and is_tasks is False:
             self.print_options()
-            self.print_splash_prompt()
+            self.print_splash_prompt(mode)
         elif is_options is False and is_tasks is True:
             self.print_tasks(tasks)
-            self.print_splash_prompt()
+            self.print_splash_prompt(mode)
             self.print_offer_options()
         elif is_options is True and is_tasks is True:
             self.print_tasks(tasks)
             self.print_options()
-            self.print_splash_prompt()
+            self.print_splash_prompt(mode)
         else:
-            self.print_splash_prompt()
+            self.print_splash_prompt(mode)
             self.print_offer_options()
 
     def print_tasks(self, tasks: List = None):
@@ -259,7 +261,30 @@ class Display:
             print(incomplete_tasks)
 
     def print_header_small(self):
-        print(self.col(self.ascii_header(string="SYLO", font="alligator", width=60)))
+        if self.theme_color != "rainbow":
+            print(
+                self.col(
+                    self.ascii_header(string="SYLO", font="alligator", width=60),
+                    self.theme_color,
+                )
+            )
+        else:
+            colors = ["lred", "yellow", "lgreen", "lblue", "lmagenta"]
+            shuffle(colors)
+
+            # This nasty work-around is because using ascii_header prints each letter to a new row.
+            # Forced to add E501 and W291 to flake8 config so remove them if a better solution is found for this.
+
+            print(
+                f"""      {self.col('::::::::', colors[0])}  {self.col(':::   :::', colors[1])} {self.col(':::', colors[2])}        {self.col('::::::::', colors[3])} 
+    {self.col(':+:    :+:', colors[0])} {self.col(':+:   :+:', colors[1])} {self.col(':+:', colors[2])}       {self.col(':+:    :+:', colors[3])} 
+   {self.col('+:+', colors[0])}         {self.col('+:+ +:+', colors[1])}  {self.col('+:+', colors[2])}       {self.col('+:+    +:+', colors[3])}  
+  {self.col('+#++:++#++', colors[0])}   {self.col('+#++:', colors[1])}   {self.col('+#+', colors[2])}       {self.col('+#+    +:+', colors[3])}   
+        {self.col('+#+', colors[0])}    {self.col('+#+', colors[1])}    {self.col('+#+', colors[2])}       {self.col('+#+    +#+', colors[3])}    
+{self.col('#+#    #+#', colors[0])}    {self.col('#+#', colors[1])}    {self.col('#+#', colors[2])}       {self.col('#+#    #+#', colors[3])}     
+{self.col('########', colors[0])}     {self.col('###', colors[1])}    {self.col('##########', colors[2])} {self.col('########', colors[3])}                      
+"""
+            )
 
     @staticmethod
     def color_map(color: str):
@@ -278,6 +303,7 @@ class Display:
             "lcyan": Fore.LIGHTCYAN_EX,
             "grey": Fore.LIGHTBLACK_EX,
             "lmagenta": Fore.LIGHTMAGENTA_EX,
+            "rainbow": Fore.WHITE,  # Set temporarily to white, set in print_header_small
         }
         return colors[color]
 
