@@ -42,17 +42,20 @@ from sylo.display import Display
 
 
 logger = logging.getLogger(__name__)
-display = Display()
 is_speed_mode = False
 timer_mode = "work"
 database = Database()
-cursor = display.cursor()
 initial_boot_flag = False
 
 
 class Timer:
     def __init__(
-        self, mode: str, durations: Durations, increments: int, config: Config
+        self,
+        mode: str,
+        durations: Durations,
+        increments: int,
+        config: Config,
+        display: Display,
     ):
         self.durations = durations
         self.config = config
@@ -69,6 +72,7 @@ class Timer:
             f"FROM tasks WHERE \"task_date\" = '{get_today()}' "
             f";"
         )
+        self.display = display
 
         if self.mode == "work":
             self.mins = self.durations.work.mins
@@ -84,15 +88,15 @@ class Timer:
             total=self.secs,
             position=0,
             leave=False,
-            desc=display.print_timer(self.mode, self.mins, self.tasks),
+            desc=self.display.print_timer(self.mode, self.mins, self.tasks),
             unit=" seconds",
             bar_format="%s{l_bar}%s%s{bar}%s%s{r_bar}%s"
             % (
-                display.color_map(self.config.theme_color),
+                self.display.color_map(self.config.theme_color),
                 Fore.RESET,
-                display.color_map(self.bar_color),
+                self.display.color_map(self.bar_color),
                 Fore.RESET,
-                display.color_map(self.config.theme_color),
+                self.display.color_map(self.config.theme_color),
                 Fore.RESET,
             ),
             smoothing=True,
@@ -156,11 +160,12 @@ class Sound:
 
 
 class Insights:
-    def __init__(self):
+    def __init__(self, display: Display):
         self.data_file = INSIGHTS_FILE_SESSIONS
         self.poms_file = INSIGHTS_FILE_POMS
         self.heatmap_start_date = ONE_YEAR_AGO
         self.bar_start_date = FORTNIGHT_AGO
+        self.display = display
 
     def save_files(self):
         csv_writer = csv.writer(open(self.data_file, "w"))
@@ -187,8 +192,8 @@ class Insights:
 
     def print_bar(self):
         global initial_boot_flag
-        display.print_header_small()
-        display.print_bar_header()
+        self.display.print_header_small()
+        self.display.print_bar_header()
         if initial_boot_flag is False:
             logger.info(f"Running ${self._bar_chart()}")
             run_subprocess(self._bar_chart())
@@ -197,7 +202,7 @@ class Insights:
 
     def print_heat(self):
         logger.info(f"Running ${self._heat_map()}")
-        display.print_heat_header()
+        self.display.print_heat_header()
         run_subprocess(self._heat_map())
 
     def _bar_chart(self):
@@ -241,6 +246,7 @@ class Sylo:
         tasks_date: str = None,
         speed_mode: bool = is_speed_mode,
         config: Config = None,
+        display: Display = None,
     ):
         self.durations = durations
         self.sound_obj = sound_obj
@@ -252,6 +258,7 @@ class Sylo:
         self.speed_mode = speed_mode
         self.increments = 1
         self.config = config
+        self.display = display
 
     def on_boot(self):
         clear_screen()
@@ -261,9 +268,8 @@ class Sylo:
             self.increments = COUNTDOWN_INCREMENTS
         logger.debug(f"Running in {self.increments} second increments")
 
-    def splash(self, timer: Timer):
-        display.print_splash_variants(
-            timer.durations,
+    def splash(self):
+        self.display.print_splash_variants(
             mode=self.mode,
             is_options=self.show_options,
             is_tasks=self.show_tasks,
@@ -272,7 +278,7 @@ class Sylo:
 
     def show_task(self, dates, with_id: bool = False):
         for date in dates:
-            print(display.col(f"---------------------------- {date}"))
+            print(self.display.col(f"---------------------------- {date}"))
             self.tasks = database.select(
                 f"SELECT"
                 f'"id",'
@@ -284,23 +290,24 @@ class Sylo:
                 f";"
             )
             if with_id is False:
-                display.print_tasks(self.tasks)
+                self.display.print_tasks(self.tasks)
             else:
-                display.print_tasks_with_id(self.tasks)
+                self.display.print_tasks_with_id(self.tasks)
             logger.info(f"Tasks: {self.tasks}")
 
     def task_menu_new(self, dates: List):
         task = Task()
-        display.print_new_task()
-        task.description = input(display.col("Description >> ", "yellow"))
+        self.display.print_new_task()
+        task.description = input(self.display.col("Description >> ", "yellow"))
         task.effort = input(
-            display.col(
-                f"Effort (in" f" {display.add_plurality(display.pom_name)}) >> ",
+            self.display.col(
+                f"Effort (in"
+                f" {self.display.add_plurality(self.display.pom_name)}) >> ",
                 "yellow",
             )
         )
         while task.effort.isnumeric() is False:
-            print(display.col("MUST BE NUMERIC", "red"))
+            print(self.display.col("MUST BE NUMERIC", "red"))
             sleep(1)
             self.task_menu(dates)
         task.write_task_to_db()
@@ -308,12 +315,12 @@ class Sylo:
 
     def task_menu_close(self, dates: List, task_ids: List[tuple]):
         clear_screen()
-        display.print_header_small()
+        self.display.print_header_small()
         self.show_task(dates, True)
-        display.print_edit_task()
-        comp_input = input(display.col("Task id >> ", "yellow"))
+        self.display.print_edit_task()
+        comp_input = input(self.display.col("Task id >> ", "yellow"))
         while valid_input(comp_input, task_ids) is False:
-            print(display.col("NOT A VALID ID", "red"))
+            print(self.display.col("NOT A VALID ID", "red"))
             sleep(1)
             self.task_menu(dates)
         database.execute(
@@ -325,12 +332,12 @@ class Sylo:
 
     def task_menu_move(self, dates: List, task_ids: List[tuple]):
         clear_screen()
-        display.print_header_small()
+        self.display.print_header_small()
         self.show_task(dates, True)
-        display.print_edit_task()
-        comp_input = input(display.col("Task id >> ", "yellow"))
+        self.display.print_edit_task()
+        comp_input = input(self.display.col("Task id >> ", "yellow"))
         while valid_input(comp_input, task_ids) is False:
-            print(display.col("NOT A VALID ID", "red"))
+            print(self.display.col("NOT A VALID ID", "red"))
             sleep(1)
             self.task_menu(dates)
         database.execute(
@@ -341,12 +348,12 @@ class Sylo:
 
     def task_menu_delete(self, dates: List, task_ids: List[tuple]):
         clear_screen()
-        display.print_header_small()
+        self.display.print_header_small()
         self.show_task(dates, True)
-        display.print_remove_task()
-        comp_input = input(display.col("Task id >> ", "yellow"))
+        self.display.print_remove_task()
+        comp_input = input(self.display.col("Task id >> ", "yellow"))
         while valid_input(comp_input, task_ids) is False:
-            print(display.col("NOT A VALID ID", "red"))
+            print(self.display.col("NOT A VALID ID", "red"))
             sleep(1)
             self.task_menu(dates)
         database.execute(f"DELETE FROM tasks" f' WHERE "id" = {comp_input};')
@@ -366,10 +373,10 @@ class Sylo:
             f";"
         )
         all_task_ids = [i[0] for i in all_tasks]
-        display.print_header_small()
+        self.display.print_header_small()
         self.show_task(dates)
-        display.print_add_task_or_quit()
-        usr_input = input(cursor)
+        self.display.print_add_task_or_quit()
+        usr_input = input(self.display.cursor())
         while valid_input(usr_input, INPUT_OPTIONS["task_menu"]) is False:
             self.task_menu(dates)
         if usr_input == "":
@@ -395,12 +402,12 @@ class Sylo:
 
     def show_insights_menu(self):
         clear_screen()
-        metrics = Insights()
+        metrics = Insights(self.display)
         metrics.save_files()
         metrics.print_bar()
         metrics.print_heat()
-        display.print_insights(durations=self.durations)
-        input(cursor)
+        self.display.print_insights()
+        input(self.display.cursor())
         self.home_loop()
 
     def timer_loop(self, timer: Timer):
@@ -468,9 +475,10 @@ class Sylo:
             durations=self.durations,
             config=self.config,
             increments=self.increments,
+            display=self.display,
         )
-        self.splash(timer)
-        response = get_input(cursor)
+        self.splash()
+        response = get_input(self.display.cursor())
         logger.info(f"User response: {response}")
         while valid_input(response, INPUT_OPTIONS["home"]) is False:
             self.show_options = True
@@ -497,13 +505,14 @@ def virgin_boostrap():
     run_subprocess(HOME_DIR_CREATE)
 
 
-def config_allocation(args, config, durations: Durations):
+def config_allocation(args, config, durations: Durations, display: Display):
     config_file = ConfigFile()
     config_file.set_config(config, durations)
     logger.info(config.theme_color)
     if args.theme:
         config.theme_color = args.theme
     logger.info(config.theme_color)
+    display.theme_color = config.theme_color
     display.theme = display.color_map(config.theme_color)
     display.pom_name = config.pom_name
     logger.info(display.theme)
@@ -521,7 +530,8 @@ def run(args, config):
     global is_speed_mode, timer_mode
 
     durations_data = Durations()
-    config_allocation(args, config, durations_data)
+    display = Display(durations=durations_data)
+    config_allocation(args, config, durations_data, display)
     sound = Sound(config.audio_file)
     sound.initialise()
 
@@ -559,5 +569,6 @@ def run(args, config):
             f";"
         ),
         config=config,
+        display=display,
     )
     sylo.home_loop()
